package alfred.web.core

import org.springframework.stereotype.Service
import java.nio.file.Path
import java.nio.file.Paths
import java.util.UUID
import kotlin.collections.isNotEmpty

@Service
class Workspaces {

    fun withWorkspace(ctx: BuildContext, block: (Path) -> Unit) {
        val workspacePath = Paths.get(
            ctx.config.gitWorkspace, UUID.randomUUID().toString()
        )
        val workspaceDir = workspacePath.toFile()

        ctx.logFile.header(ctx.buildId, ctx.rev, workspacePath)

        if (!workspaceDir.exists()) {
            workspaceDir.mkdirs()
        }

        val wsList = workspaceDir.list()
        if (wsList != null && wsList.isNotEmpty()) {
            throw WorkspaceIsNotEmpty(workspaceDir.toString())
        }

        try {
            block(workspaceDir.toPath())
        } finally {
            ctx.logFile.footer()
            workspaceDir.deleteRecursively()
        }
    }

}